@@ -124,12 +124,14 @@ extern int _XGetBitsPerPixel(Display *dpy, int depth);
 
 extern char dispatchExceptionAtReset;
 
-extern const char *__progname;
+const char *nxagentProgName;
 
 char nxagentDisplayName[NXAGENTDISPLAYNAMELENGTH];
 Bool nxagentSynchronize = False;
 Bool nxagentRealWindowProp = False;
 
+Bool nxagentAutoDPI = False;
+
 char nxagentShadowDisplayName[NXAGENTSHADOWDISPLAYNAMELENGTH] = {0};
 
 char nxagentWindowName[NXAGENTWINDOWNAMELENGTH];
@@ -185,6 +187,8 @@ int ddxProcessArgument(int argc, char *argv[], int i)
    * Ensure that the options are set to their defaults.
    */
 
+  nxagentProgName = argv[0];
+
   static Bool resetOptions = True;
 
   if (resetOptions == True)
@@ -336,6 +340,12 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 0;
   }
 
+  if (!strcmp(argv[i], "-version"))
+  {
+    nxagentShowVersionInfo();
+    exit(0);
+  }
+
   /*
    * This had to be '-options' since the beginning
    * but was '-option' by mistake. Now we have to
@@ -676,6 +686,10 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 1;
   }
 
+  if (!strcmp(argv[i], "-nomagicpixel")) {
+    nxagentChangeOption(MagicPixel, 0);
+    return 1;
+  }
 
   if (!strcmp(argv[i], "-noonce"))
   {
@@ -731,6 +745,11 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 1;
   }
 
+  if (!strcmp(argv[i], "-autodpi")) {
+    nxagentAutoDPI = True;
+    return 1;
+  }
+
   /*
    * The original -noreset option, disabling
    * dispatchExceptionAtReset, is the default.
@@ -1175,13 +1194,13 @@ static void nxagentParseOptions(char *name, char *value)
   {
 #if !defined(PANORAMIX) && !defined(RANDR)
     nxagentChangeOption(Xinerama, 0);
-    fprintf(stderr, "Warning: No Xinerama support compiled into %s.\n", __progname);
+    fprintf(stderr, "Warning: No Xinerama support compiled into %s.\n", nxagentProgName);
     return;
 #else
     if (PANORAMIX_DISABLED_COND && RRXINERAMA_DISABLED_COND)
     {
       nxagentChangeOption(Xinerama, 0);
-      fprintf(stderr, "Warning: XINERAMA extension has been disabled on %s startup.\n", __progname);
+      fprintf(stderr, "Warning: XINERAMA extension has been disabled on %s startup.\n", nxagentProgName);
       return;
     }
 
@@ -1246,6 +1265,38 @@ static void nxagentParseOptions(char *name, char *value)
 
     return;
   }
+  else if (!strcmp(name, "magicpixel"))
+  {
+    if (!strcmp(value, "0"))
+    {
+      nxagentChangeOption(MagicPixel, 0);
+    }
+    else
+    {
+      nxagentChangeOption(MagicPixel, 1);
+    }
+
+    return;
+  }
+  else if (!strcmp(name, "autodpi"))
+  {
+    if (nxagentReconnectTrap == True)
+    {
+      #ifdef DEBUG
+      fprintf(stderr, "nxagentParseOptions: Ignoring option 'autodpi' at reconnection.\n");
+      #endif
+    }
+    else if (!strcmp(value, "0"))
+    {
+      nxagentAutoDPI = False;
+    }
+    else
+    {
+      nxagentAutoDPI = True;
+    }
+
+    return;
+  }
   else if (strcmp(name, "shadowuid") == 0)
   {
     nxagentShadowUid = atoi(value);
@@ -2058,10 +2109,8 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
     return useNXTrans;
 }
 
-void ddxUseMsg()
+void ddxUseMsg(void)
 {
-  ErrorF("-display string        display name of the real server\n");
-  ErrorF("-sync                  synchronize with the real server\n");
   ErrorF("-full                  utilize full regeneration\n");
   ErrorF("-class string          default visual class\n");
   ErrorF("-depth int             default depth\n");
@@ -2071,10 +2120,15 @@ void ddxUseMsg()
   ErrorF("-scrns int             number of screens to generate\n");
   ErrorF("-install               install colormaps directly\n");
 
-  ErrorF("The NX system adds the following arguments:\n");
+  ErrorF("\nThe NX system adds the following arguments:\n");
+  ErrorF("-options file|string   file or string containing nx/nx options\n");
   ErrorF("-forcenx               force use of NX protocol messages assuming communication through nxproxy\n");
   ErrorF("-timeout int           auto-disconnect timeout in seconds (minimum allowed: 60)\n");
   ErrorF("-norootlessexit        don't exit if there are no clients in rootless mode\n");
+  ErrorF("-nomagicpixel          disable nxagent's magic pixel\n");
+  ErrorF("-autodpi               detect real server's DPI and use that in the session\n");
+  ErrorF("-display string        display name of the real server\n");
+  ErrorF("-sync                  synchronize with the real server\n");
 #ifdef RENDER
   ErrorF("-norender              disable the use of the render extension\n");
   ErrorF("-nocomposite           disable the use of the composite extension\n");
@@ -2094,9 +2148,10 @@ void ddxUseMsg()
   ErrorF("-R                     enable rootless mode\n");
   ErrorF("-S                     enable shadow mode\n");
   ErrorF("-B                     enable proxy binding mode\n");
+  ErrorF("-version               show version information and exit\n");
 }
 
-static int nxagentGetDialogName()
+static int nxagentGetDialogName(void)
 {
   if (*nxagentSessionId != '\0')
   {
@@ -2280,7 +2335,7 @@ void nxagentSetPackMethod(void)
  *          of involved drawables.
  */
 
-void nxagentSetDeferLevel()
+void nxagentSetDeferLevel(void)
 {
   int deferLevel;
   int tileWidth;
@@ -2460,7 +2515,7 @@ void nxagentSetDeferLevel()
   }
 }
 
-void nxagentSetBufferSize()
+void nxagentSetBufferSize(void)
 {
   int size;
 
@@ -2519,7 +2574,7 @@ void nxagentSetBufferSize()
   }
 }
 
-void nxagentSetScheduler()
+void nxagentSetScheduler(void)
 {
   /*
    * The smart scheduler is the default.
@@ -2535,7 +2590,7 @@ void nxagentSetScheduler()
   }
 }
 
-void nxagentSetCoalescence()
+void nxagentSetCoalescence(void)
 {
   int timeout;
 
@@ -2591,3 +2646,7 @@ void nxagentSetCoalescence()
   nxagentChangeOption(DisplayCoalescence, timeout);
 }
 
+void nxagentShowVersionInfo(void)
+{
+    ErrorF("NXAGENT - Version " NX_VERSION_CURRENT_STRING "\n");
+}
