@@ -56,7 +56,7 @@ unsigned int nxagentPrintGeometryFlags = 0;
  * the options repository to the default values.
  */
 
-void nxagentInitOptions()
+void nxagentInitOptions(void)
 {
   nxagentOptions.LinkType = UNDEFINED;
 
@@ -155,6 +155,8 @@ void nxagentInitOptions()
 
   nxagentOptions.Menu = 1;
 
+  nxagentOptions.MagicPixel = 1;
+
   nxagentOptions.ClientOs = UNDEFINED;
 
   nxagentOptions.InhibitXkb = 1;
@@ -181,7 +183,7 @@ void nxagentInitOptions()
  * ting.
  */
 
-void nxagentResetOptions()
+void nxagentResetOptions(void)
 {
   if (nxagentLockDeferLevel == 0)
   {
@@ -199,12 +201,12 @@ void nxagentResetOptions()
   nxagentOptions.KeycodeConversion = DEFAULT_KEYCODE_CONVERSION;
 }
 
-void nxagentSaveOptions()
+void nxagentSaveOptions(void)
 {
   memcpy(&nxagentOptionsBackup, &nxagentOptions, sizeof(AgentOptionsRec));
 }
 
-void nxagentRestoreOptions()
+void nxagentRestoreOptions(void)
 {
   nxagentOptions.DeferLevel   = nxagentOptionsBackup.DeferLevel;
   nxagentOptions.DeferTimeout = nxagentOptionsBackup.DeferTimeout;
