@@ -118,7 +118,7 @@ static void nxagentRemovePropertyFromList(void);
 
 static void nxagentPrintRootlessTopLevelWindowMap(void);
 
-void nxagentPrintRootlessTopLevelWindowMap()
+void nxagentPrintRootlessTopLevelWindowMap(void)
 {
   int i;
 
@@ -245,7 +245,7 @@ void nxagentCirculateRootlessWindows(int direction)
 
 #ifdef DEBUG
 
-Bool nxagentRootlessTreesMatch()
+Bool nxagentRootlessTreesMatch(void)
 {
   Window root_return;
   Window parent_return;
@@ -1002,7 +1002,7 @@ void nxagentImportProperty(Window window,
         wmHints.flags &= ~IconWindowHint;
 
         #ifdef WARNING
-        fprintf(stderr, "nxagenImportProperty: WARNING! Failed to look up remote icon "
+        fprintf(stderr, "nxagentImportProperty: WARNING! Failed to look up remote icon "
                     "window %x from hint importing property [%ld] type %s on window %p.\n",
                          (unsigned int) wmHints.icon_window,
                              (long int) property, typeS, (void *) pWin);
@@ -1178,7 +1178,7 @@ static struct{
  * Removing first element from list.
  */
 
-void nxagentRemovePropertyFromList()
+void nxagentRemovePropertyFromList(void)
 {
   struct nxagentPropertyRec *tmp = nxagentPropertyList.first;
 
@@ -1242,7 +1242,7 @@ void nxagentAddPropertyToList(Atom property, WindowPtr pWin)
   nxagentPropertyList.size++;
 }
 
-void nxagentFreePropertyList()
+void nxagentFreePropertyList(void)
 {
   while (nxagentPropertyList.size != 0)
   {
