@@ -71,7 +71,7 @@ DrawablePtr nxagentSplitDrawable(DrawablePtr pDrawable)
   }
 }
 
-void nxagentInitSplitResources()
+void nxagentInitSplitResources(void)
 {
   int resource;
 
@@ -93,7 +93,7 @@ void nxagentInitSplitResources()
   }
 }
 
-SplitResourcePtr nxagentAllocSplitResource()
+SplitResourcePtr nxagentAllocSplitResource(void)
 {
   int resource;
 
@@ -193,14 +193,14 @@ void nxagentFreeSplitResource(SplitResourcePtr pResource)
   pResource -> gc       = NULL;
 }
 
-void nxagentInitUnpackResources()
+void nxagentInitUnpackResources(void)
 {
 /*
 FIXME: This must be implemented.
 */
 }
 
-UnpackResourcePtr nxagentAllocUnpackResource()
+UnpackResourcePtr nxagentAllocUnpackResource(void)
 {
 /*
 FIXME: This must be implemented.
@@ -492,14 +492,14 @@ void nxagentReleaseSplit(DrawablePtr pDrawable)
                   "commits are invalid.\n", pResource -> split);
       #endif
 
-      FatalError("nxagentCheckSplit: PANIC! Found a region for resource [%d] but the "
+      FatalError("nxagentReleaseSplit: PANIC! Found a region for resource [%d] but the "
                      "commits are invalid.\n", pResource -> split);
     }
 
     #endif
 
     #ifdef TEST
-    fprintf(stderr, "nxagentValidateSplit: Aborting the data transfer for resource [%d].\n",
+    fprintf(stderr, "nxagentReleaseSplit: Aborting the data transfer for resource [%d].\n",
                 pResource -> split);
     #endif
 
@@ -734,7 +734,7 @@ void nxagentWaitDrawable(DrawablePtr pDrawable)
   if (pResource == NULL)
   {
     #ifdef TEST
-    fprintf(stderr, "++++++nxagentWaitDrawable: WARNING! The drawable at [%p] is already awake.\n",
+    fprintf(stderr, "nxagentWaitDrawable: WARNING! The drawable at [%p] is already awake.\n",
 	    (void *) pDrawable);
     #endif
 
@@ -742,7 +742,7 @@ void nxagentWaitDrawable(DrawablePtr pDrawable)
   }
 
   #ifdef TEST
-  fprintf(stderr, "++++++nxagentWaitDrawable: Waiting drawable at [%p] with resource [%d].\n",
+  fprintf(stderr, "nxagentWaitDrawable: Waiting drawable at [%p] with resource [%d].\n",
               (void *) pDrawable, pResource -> split);
   #endif
 
@@ -786,12 +786,12 @@ void nxagentWaitDrawable(DrawablePtr pDrawable)
 
       if (NXDisplayError(nxagentDisplay) == 1)
       {
-        fprintf(stderr, "++++++nxagentWaitDrawable: WARNING! Display error detected while "
+        fprintf(stderr, "nxagentWaitDrawable: WARNING! Display error detected while "
                     "waiting for the drawable.\n");
       }
       else
       {
-        fprintf(stderr, "++++++nxagentWaitDrawable: Drawable at [%p] can now be restarted.\n",
+        fprintf(stderr, "nxagentWaitDrawable: Drawable at [%p] can now be restarted.\n",
 		(void *) pDrawable);
       }
 
@@ -801,7 +801,7 @@ void nxagentWaitDrawable(DrawablePtr pDrawable)
     }
 
     #ifdef TEST
-    fprintf(stderr, "++++++nxagentWaitDrawable: Yielding control to the NX transport.\n");
+    fprintf(stderr, "nxagentWaitDrawable: Yielding control to the NX transport.\n");
     #endif
 
     nxagentWaitEvents(nxagentDisplay, NULL);
@@ -1173,7 +1173,7 @@ FIXME: Implementing the valid region policy
   #endif
 }
 
-void nxagentHandleEmptySplitEvent()
+void nxagentHandleEmptySplitEvent(void)
 {
 /*
 FIXME: Should run a consistency check here.
