@@ -30,7 +30,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <config.h>
 #endif
 
-
 #include <stdio.h>
 #include <nx-X11/X.h>
 #include <nx-X11/Xproto.h>
@@ -39,7 +38,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <nx-X11/keysym.h>
 #include <xkbsrv.h>
 
-
 /***====================================================================***/
 
 Status
@@ -298,7 +296,7 @@ XkbClientMapPtr	map;
 	    }
 	}
     }
-    if ((!map)||(!map->types)||(!map->num_types<XkbNumRequiredTypes)) {
+    if ((!map)||(!map->types)||(!(map->num_types<XkbNumRequiredTypes))) {
 	tmp= XkbNumRequiredTypes+1;
 	if (XkbAllocClientMap(xkb,XkbKeyTypesMask,tmp)!=Success)
 	    return NULL;
